# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.override_batch_in import OverrideBatchIn  # noqa: E501

class TestOverrideBatchIn(unittest.TestCase):
    """OverrideBatchIn unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OverrideBatchIn:
        """Test OverrideBatchIn
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OverrideBatchIn`
        """
        model = OverrideBatchIn()  # noqa: E501
        if include_optional:
            return OverrideBatchIn(
                portal_id = 56,
                created_by = 56,
                items = [
                    access_server_connector.models.override_item.OverrideItem(
                        member_id = 56, 
                        resource_type = 'course', 
                        resource_id = 56, 
                        is_active = True, 
                        rule = null, )
                    ]
            )
        else:
            return OverrideBatchIn(
                portal_id = 56,
                items = [
                    access_server_connector.models.override_item.OverrideItem(
                        member_id = 56, 
                        resource_type = 'course', 
                        resource_id = 56, 
                        is_active = True, 
                        rule = null, )
                    ],
        )
        """

    def testOverrideBatchIn(self):
        """Test OverrideBatchIn"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
