# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ReasonStatus(str, Enum):
    """
    ReasonStatus
    """

    """
    allowed enum values
    """
    ACTIVE = 'active'
    SETTLED = 'settled'
    LAPSED = 'lapsed'
    DEFAULTED = 'defaulted'
    REVOKED = 'revoked'

    @classmethod
    def from_json(cls, json_str: str) -> ReasonStatus:
        """Create an instance of ReasonStatus from a JSON string"""
        return ReasonStatus(json.loads(json_str))


