# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.resolve_out import ResolveOut  # noqa: E501

class TestResolveOut(unittest.TestCase):
    """ResolveOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResolveOut:
        """Test ResolveOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResolveOut`
        """
        model = ResolveOut()  # noqa: E501
        if include_optional:
            return ResolveOut(
                root = access_server_connector.models.node_access_out.NodeAccessOut(
                    resource_type = 'course', 
                    resource_id = 56, 
                    state = 'available', 
                    allowed = True, 
                    available_at = 56, 
                    expires_at = 56, 
                    lock_reason = null, 
                    winning_layer = null, 
                    reasons = [
                        56
                        ], 
                    expired_message = '', 
                    children = [
                        access_server_connector.models.node_access_out.NodeAccessOut(
                            resource_type = 'course', 
                            resource_id = 56, 
                            state = 'available', 
                            allowed = True, 
                            available_at = 56, 
                            expires_at = 56, 
                            lock_reason = null, 
                            winning_layer = null, 
                            reasons = [
                                56
                                ], 
                            expired_message = '', 
                            children = [
                                
                                ], )
                        ], ),
                next_transition = 56
            )
        else:
            return ResolveOut(
                root = access_server_connector.models.node_access_out.NodeAccessOut(
                    resource_type = 'course', 
                    resource_id = 56, 
                    state = 'available', 
                    allowed = True, 
                    available_at = 56, 
                    expires_at = 56, 
                    lock_reason = null, 
                    winning_layer = null, 
                    reasons = [
                        56
                        ], 
                    expired_message = '', 
                    children = [
                        access_server_connector.models.node_access_out.NodeAccessOut(
                            resource_type = 'course', 
                            resource_id = 56, 
                            state = 'available', 
                            allowed = True, 
                            available_at = 56, 
                            expires_at = 56, 
                            lock_reason = null, 
                            winning_layer = null, 
                            reasons = [
                                56
                                ], 
                            expired_message = '', 
                            children = [
                                
                                ], )
                        ], ),
                next_transition = 56,
        )
        """

    def testResolveOut(self):
        """Test ResolveOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
