# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_public_package_out import WrappedResponsePublicPackageOut  # noqa: E501

class TestWrappedResponsePublicPackageOut(unittest.TestCase):
    """WrappedResponsePublicPackageOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponsePublicPackageOut:
        """Test WrappedResponsePublicPackageOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponsePublicPackageOut`
        """
        model = WrappedResponsePublicPackageOut()  # noqa: E501
        if include_optional:
            return WrappedResponsePublicPackageOut(
                done = True,
                result = access_server_connector.models.public_package_out.PublicPackageOut(
                    id = 56, 
                    title = '', 
                    payment_type = '', 
                    sales_page_url = '', 
                    is_active = True, )
            )
        else:
            return WrappedResponsePublicPackageOut(
                result = access_server_connector.models.public_package_out.PublicPackageOut(
                    id = 56, 
                    title = '', 
                    payment_type = '', 
                    sales_page_url = '', 
                    is_active = True, ),
        )
        """

    def testWrappedResponsePublicPackageOut(self):
        """Test WrappedResponsePublicPackageOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
