# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.access_order_event import AccessOrderEvent  # noqa: E501

class TestAccessOrderEvent(unittest.TestCase):
    """AccessOrderEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessOrderEvent:
        """Test AccessOrderEvent
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccessOrderEvent`
        """
        model = AccessOrderEvent()  # noqa: E501
        if include_optional:
            return AccessOrderEvent(
                event_id = '',
                occurred_at = 56,
                portal_id = 56,
                member_id = 56,
                reason_kind = 'order',
                product = access_server_connector.models.event_product.EventProduct(
                    provider = '', 
                    external_product_id = '', 
                    marketplace_product_id = 56, ),
                access_package_ids = [
                    56
                    ],
                order = access_server_connector.models.event_order.EventOrder(
                    external_order_id = '', 
                    payment_type = '', 
                    is_test = True, ),
                status = 'active',
                status_reason = '',
                subscription = access_server_connector.models.event_subscription.EventSubscription(
                    external_subscription_id = '', 
                    current_period_end = 56, 
                    grace_until = 56, )
            )
        else:
            return AccessOrderEvent(
                event_id = '',
                occurred_at = 56,
                portal_id = 56,
                member_id = 56,
                status = 'active',
        )
        """

    def testAccessOrderEvent(self):
        """Test AccessOrderEvent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
