# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class ProductLinkOut(BaseModel):
    """
    ProductLinkOut
    """
    id: StrictInt = Field(...)
    marketplace_product_id: StrictInt = Field(...)
    provider: Optional[StrictStr] = Field(...)
    external_product_id: Optional[StrictStr] = Field(...)
    __properties = ["id", "marketplace_product_id", "provider", "external_product_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProductLinkOut:
        """Create an instance of ProductLinkOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if provider (nullable) is None
        # and __fields_set__ contains the field
        if self.provider is None and "provider" in self.__fields_set__:
            _dict['provider'] = None

        # set to None if external_product_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_product_id is None and "external_product_id" in self.__fields_set__:
            _dict['external_product_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProductLinkOut:
        """Create an instance of ProductLinkOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ProductLinkOut.parse_obj(obj)

        _obj = ProductLinkOut.parse_obj({
            "id": obj.get("id"),
            "marketplace_product_id": obj.get("marketplace_product_id"),
            "provider": obj.get("provider"),
            "external_product_id": obj.get("external_product_id")
        })
        return _obj


