# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.course_tree_out import CourseTreeOut  # noqa: E501

class TestCourseTreeOut(unittest.TestCase):
    """CourseTreeOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseTreeOut:
        """Test CourseTreeOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseTreeOut`
        """
        model = CourseTreeOut()  # noqa: E501
        if include_optional:
            return CourseTreeOut(
                course = access_server_connector.models.access_result_out.AccessResultOut(
                    resource_type = 'course', 
                    resource_id = 56, 
                    state = 'available', 
                    allowed = True, 
                    available_at = 56, 
                    expires_at = 56, 
                    lock_reason = null, 
                    winning_layer = null, 
                    reasons = [
                        56
                        ], 
                    expired_message = '', ),
                modules = [
                    access_server_connector.models.module_tree_out.ModuleTreeOut(
                        module = access_server_connector.models.access_result_out.AccessResultOut(
                            resource_type = 'course', 
                            resource_id = 56, 
                            state = 'available', 
                            allowed = True, 
                            available_at = 56, 
                            expires_at = 56, 
                            lock_reason = null, 
                            winning_layer = null, 
                            reasons = [
                                56
                                ], 
                            expired_message = '', ), 
                        lessons = [
                            access_server_connector.models.access_result_out.AccessResultOut(
                                resource_type = 'course', 
                                resource_id = 56, 
                                state = 'available', 
                                allowed = True, 
                                available_at = 56, 
                                expires_at = 56, 
                                lock_reason = null, 
                                winning_layer = null, 
                                reasons = [
                                    56
                                    ], 
                                expired_message = '', )
                            ], )
                    ],
                next_transition = 56
            )
        else:
            return CourseTreeOut(
                course = access_server_connector.models.access_result_out.AccessResultOut(
                    resource_type = 'course', 
                    resource_id = 56, 
                    state = 'available', 
                    allowed = True, 
                    available_at = 56, 
                    expires_at = 56, 
                    lock_reason = null, 
                    winning_layer = null, 
                    reasons = [
                        56
                        ], 
                    expired_message = '', ),
                modules = [
                    access_server_connector.models.module_tree_out.ModuleTreeOut(
                        module = access_server_connector.models.access_result_out.AccessResultOut(
                            resource_type = 'course', 
                            resource_id = 56, 
                            state = 'available', 
                            allowed = True, 
                            available_at = 56, 
                            expires_at = 56, 
                            lock_reason = null, 
                            winning_layer = null, 
                            reasons = [
                                56
                                ], 
                            expired_message = '', ), 
                        lessons = [
                            access_server_connector.models.access_result_out.AccessResultOut(
                                resource_type = 'course', 
                                resource_id = 56, 
                                state = 'available', 
                                allowed = True, 
                                available_at = 56, 
                                expires_at = 56, 
                                lock_reason = null, 
                                winning_layer = null, 
                                reasons = [
                                    56
                                    ], 
                                expired_message = '', )
                            ], )
                    ],
                next_transition = 56,
        )
        """

    def testCourseTreeOut(self):
        """Test CourseTreeOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
