# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class UnlockType(str, Enum):
    """
    UnlockType
    """

    """
    allowed enum values
    """
    IMMEDIATE = 'immediate'
    AFTER_DAYS = 'after_days'
    ON_WEEKDAY = 'on_weekday'
    AFTER_DAYS_THEN_WEEKDAY = 'after_days_then_weekday'
    FIXED_DATE = 'fixed_date'

    @classmethod
    def from_json(cls, json_str: str) -> UnlockType:
        """Create an instance of UnlockType from a JSON string"""
        return UnlockType(json.loads(json_str))


