# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from access_server_connector.models.unlock_type import UnlockType

class UnlockSpec(BaseModel):
    """
    UnlockSpec
    """
    type: Optional[UnlockType] = None
    days: Optional[StrictInt] = None
    weekday: Optional[StrictInt] = None
    weekdays: Optional[conlist(StrictInt)] = None
    var_date: Optional[StrictInt] = Field(default=None, alias="date")
    __properties = ["type", "days", "weekday", "weekdays", "date"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UnlockSpec:
        """Create an instance of UnlockSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if days (nullable) is None
        # and __fields_set__ contains the field
        if self.days is None and "days" in self.__fields_set__:
            _dict['days'] = None

        # set to None if weekday (nullable) is None
        # and __fields_set__ contains the field
        if self.weekday is None and "weekday" in self.__fields_set__:
            _dict['weekday'] = None

        # set to None if weekdays (nullable) is None
        # and __fields_set__ contains the field
        if self.weekdays is None and "weekdays" in self.__fields_set__:
            _dict['weekdays'] = None

        # set to None if var_date (nullable) is None
        # and __fields_set__ contains the field
        if self.var_date is None and "var_date" in self.__fields_set__:
            _dict['date'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UnlockSpec:
        """Create an instance of UnlockSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UnlockSpec.parse_obj(obj)

        _obj = UnlockSpec.parse_obj({
            "type": obj.get("type"),
            "days": obj.get("days"),
            "weekday": obj.get("weekday"),
            "weekdays": obj.get("weekdays"),
            "var_date": obj.get("date")
        })
        return _obj


