# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_list_package_out import WrappedResponseListPackageOut  # noqa: E501

class TestWrappedResponseListPackageOut(unittest.TestCase):
    """WrappedResponseListPackageOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseListPackageOut:
        """Test WrappedResponseListPackageOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseListPackageOut`
        """
        model = WrappedResponseListPackageOut()  # noqa: E501
        if include_optional:
            return WrappedResponseListPackageOut(
                done = True,
                result = [
                    access_server_connector.models.package_out.PackageOut(
                        id = 56, 
                        portal_id = 56, 
                        title = '', 
                        payment_type = '', 
                        is_active = True, 
                        is_locked = True, 
                        direct_link_slug = '', 
                        sales_page_url = '', 
                        expired_message = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ]
            )
        else:
            return WrappedResponseListPackageOut(
                result = [
                    access_server_connector.models.package_out.PackageOut(
                        id = 56, 
                        portal_id = 56, 
                        title = '', 
                        payment_type = '', 
                        is_active = True, 
                        is_locked = True, 
                        direct_link_slug = '', 
                        sales_page_url = '', 
                        expired_message = '', 
                        created_at = 56, 
                        updated_at = 56, )
                    ],
        )
        """

    def testWrappedResponseListPackageOut(self):
        """Test WrappedResponseListPackageOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
