# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.packages_api import PackagesApi  # noqa: E501


class TestPackagesApi(unittest.IsolatedAsyncioTestCase):
    """PackagesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = PackagesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_count_members_v1_packages_access_package_id_members_count_get(self) -> None:
        """Test case for count_members_v1_packages_access_package_id_members_count_get

        Count members who have access to this package  # noqa: E501
        """
        pass

    async def test_count_packages_v1_packages_count_get(self) -> None:
        """Test case for count_packages_v1_packages_count_get

        Count a portal's access packages  # noqa: E501
        """
        pass

    async def test_create_package_v1_packages_post(self) -> None:
        """Test case for create_package_v1_packages_post

        Create an access package  # noqa: E501
        """
        pass

    async def test_delete_package_v1_packages_access_package_id_delete(self) -> None:
        """Test case for delete_package_v1_packages_access_package_id_delete

        Delete an access package  # noqa: E501
        """
        pass

    async def test_delete_rule_v1_packages_access_package_id_rules_rule_id_delete(self) -> None:
        """Test case for delete_rule_v1_packages_access_package_id_rules_rule_id_delete

        Remove an access rule from a package  # noqa: E501
        """
        pass

    async def test_get_package_by_slug_v1_packages_by_slug_slug_get(self) -> None:
        """Test case for get_package_by_slug_v1_packages_by_slug_slug_get

        Get public package data by its direct-link slug (unauthenticated)  # noqa: E501
        """
        pass

    async def test_get_package_v1_packages_access_package_id_get(self) -> None:
        """Test case for get_package_v1_packages_access_package_id_get

        Get a single access package (with its rules)  # noqa: E501
        """
        pass

    async def test_get_rules_v1_packages_access_package_id_rules_get(self) -> None:
        """Test case for get_rules_v1_packages_access_package_id_rules_get

        List a package's access rules  # noqa: E501
        """
        pass

    async def test_link_product_v1_packages_access_package_id_products_put(self) -> None:
        """Test case for link_product_v1_packages_access_package_id_products_put

        Link a marketplace product to a package  # noqa: E501
        """
        pass

    async def test_list_members_v1_packages_access_package_id_members_get(self) -> None:
        """Test case for list_members_v1_packages_access_package_id_members_get

        List members who have access to this package (paginated)  # noqa: E501
        """
        pass

    async def test_list_packages_v1_packages_get(self) -> None:
        """Test case for list_packages_v1_packages_get

        List a portal's access packages (paginated)  # noqa: E501
        """
        pass

    async def test_list_product_links_v1_packages_access_package_id_products_get(self) -> None:
        """Test case for list_product_links_v1_packages_access_package_id_products_get

        List the marketplace products linked to a package  # noqa: E501
        """
        pass

    async def test_patch_package_v1_packages_access_package_id_patch(self) -> None:
        """Test case for patch_package_v1_packages_access_package_id_patch

        Toggle is_active / is_locked  # noqa: E501
        """
        pass

    async def test_set_rule_v1_packages_access_package_id_rules_put(self) -> None:
        """Test case for set_rule_v1_packages_access_package_id_rules_put

        Set an access rule on a package  # noqa: E501
        """
        pass

    async def test_unlink_product_v1_packages_access_package_id_products_link_id_delete(self) -> None:
        """Test case for unlink_product_v1_packages_access_package_id_products_link_id_delete

        Unlink a marketplace product from a package  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
