# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ReasonKind(str, Enum):
    """
    ReasonKind
    """

    """
    allowed enum values
    """
    ORDER = 'order'
    MANUAL = 'manual'
    REWARD = 'reward'
    FREE = 'free'

    @classmethod
    def from_json(cls, json_str: str) -> ReasonKind:
        """Create an instance of ReasonKind from a JSON string"""
        return ReasonKind(json.loads(json_str))


