# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.access_api import AccessApi  # noqa: E501


class TestAccessApi(unittest.IsolatedAsyncioTestCase):
    """AccessApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = AccessApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_check_v1_access_check_post(self) -> None:
        """Test case for check_v1_access_check_post

        Check a single resource  # noqa: E501
        """
        pass

    async def test_courses_summary_v1_access_members_member_id_courses_get(self) -> None:
        """Test case for courses_summary_v1_access_members_member_id_courses_get

        List a member's course access summary  # noqa: E501
        """
        pass

    async def test_resolve_v1_access_resolve_post(self) -> None:
        """Test case for resolve_v1_access_resolve_post

        Resolve a resource tree  # noqa: E501
        """
        pass

    async def test_tree_v1_access_members_member_id_courses_course_id_tree_post(self) -> None:
        """Test case for tree_v1_access_members_member_id_courses_course_id_tree_post

        Resolve a course access tree  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
