# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.ownership_api import OwnershipApi  # noqa: E501


class TestOwnershipApi(unittest.IsolatedAsyncioTestCase):
    """OwnershipApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OwnershipApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_deactivate_v1_ownership_reasons_reason_id_deactivate_post(self) -> None:
        """Test case for deactivate_v1_ownership_reasons_reason_id_deactivate_post

        Deactivate (revoke) an ownership reason  # noqa: E501
        """
        pass

    async def test_grant_v1_ownership_grant_post(self) -> None:
        """Test case for grant_v1_ownership_grant_post

        Manually grant an access package  # noqa: E501
        """
        pass

    async def test_member_packages_count_v1_ownership_members_member_id_packages_count_get(self) -> None:
        """Test case for member_packages_count_v1_ownership_members_member_id_packages_count_get

        Count the access packages a member owns  # noqa: E501
        """
        pass

    async def test_member_packages_v1_ownership_members_member_id_packages_get(self) -> None:
        """Test case for member_packages_v1_ownership_members_member_id_packages_get

        List the access packages a member owns (paginated)  # noqa: E501
        """
        pass

    async def test_ownership_list_v1_ownership_members_member_id_reasons_get(self) -> None:
        """Test case for ownership_list_v1_ownership_members_member_id_reasons_get

        List a member's ownership reasons  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
