# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.resolve_in import ResolveIn  # noqa: E501

class TestResolveIn(unittest.TestCase):
    """ResolveIn unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResolveIn:
        """Test ResolveIn
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResolveIn`
        """
        model = ResolveIn()  # noqa: E501
        if include_optional:
            return ResolveIn(
                portal_id = 56,
                member_id = 56,
                structure = access_server_connector.models.resource_node_in.ResourceNodeIn(
                    resource_type = 'course', 
                    resource_id = 56, 
                    is_published = True, 
                    default_unlock = null, 
                    children = [
                        access_server_connector.models.resource_node_in.ResourceNodeIn(
                            resource_type = 'course', 
                            resource_id = 56, 
                            is_published = True, 
                            default_unlock = null, 
                            children = [
                                
                                ], )
                        ], )
            )
        else:
            return ResolveIn(
                portal_id = 56,
                member_id = 56,
                structure = access_server_connector.models.resource_node_in.ResourceNodeIn(
                    resource_type = 'course', 
                    resource_id = 56, 
                    is_published = True, 
                    default_unlock = null, 
                    children = [
                        access_server_connector.models.resource_node_in.ResourceNodeIn(
                            resource_type = 'course', 
                            resource_id = 56, 
                            is_published = True, 
                            default_unlock = null, 
                            children = [
                                
                                ], )
                        ], ),
        )
        """

    def testResolveIn(self):
        """Test ResolveIn"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
