# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.module_structure import ModuleStructure  # noqa: E501

class TestModuleStructure(unittest.TestCase):
    """ModuleStructure unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ModuleStructure:
        """Test ModuleStructure
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ModuleStructure`
        """
        model = ModuleStructure()  # noqa: E501
        if include_optional:
            return ModuleStructure(
                module_id = 56,
                is_published = True,
                default_unlock = access_server_connector.models.unlock_spec.UnlockSpec(
                    type = null, 
                    days = 56, 
                    weekday = 56, 
                    weekdays = [
                        56
                        ], 
                    date = 56, ),
                lessons = [
                    access_server_connector.models.lesson_structure.LessonStructure(
                        lesson_id = 56, 
                        is_published = True, 
                        default_unlock = null, )
                    ]
            )
        else:
            return ModuleStructure(
                module_id = 56,
        )
        """

    def testModuleStructure(self):
        """Test ModuleStructure"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
