# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class WinningLayer(str, Enum):
    """
    WinningLayer
    """

    """
    allowed enum values
    """
    OVERRIDE = 'override'
    AP_RULE = 'ap_rule'
    COURSE_DEFAULT = 'course_default'

    @classmethod
    def from_json(cls, json_str: str) -> WinningLayer:
        """Create an instance of WinningLayer from a JSON string"""
        return WinningLayer(json.loads(json_str))


