# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_list_ownership_reason_out import WrappedResponseListOwnershipReasonOut  # noqa: E501

class TestWrappedResponseListOwnershipReasonOut(unittest.TestCase):
    """WrappedResponseListOwnershipReasonOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseListOwnershipReasonOut:
        """Test WrappedResponseListOwnershipReasonOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseListOwnershipReasonOut`
        """
        model = WrappedResponseListOwnershipReasonOut()  # noqa: E501
        if include_optional:
            return WrappedResponseListOwnershipReasonOut(
                done = True,
                result = [
                    access_server_connector.models.ownership_reason_out.OwnershipReasonOut(
                        id = 56, 
                        access_package_id = 56, 
                        kind = 'order', 
                        status = 'active', 
                        granted_at = 56, 
                        is_test = True, )
                    ]
            )
        else:
            return WrappedResponseListOwnershipReasonOut(
                result = [
                    access_server_connector.models.ownership_reason_out.OwnershipReasonOut(
                        id = 56, 
                        access_package_id = 56, 
                        kind = 'order', 
                        status = 'active', 
                        granted_at = 56, 
                        is_test = True, )
                    ],
        )
        """

    def testWrappedResponseListOwnershipReasonOut(self):
        """Test WrappedResponseListOwnershipReasonOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
