# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.member_ownership_out import MemberOwnershipOut  # noqa: E501

class TestMemberOwnershipOut(unittest.TestCase):
    """MemberOwnershipOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MemberOwnershipOut:
        """Test MemberOwnershipOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MemberOwnershipOut`
        """
        model = MemberOwnershipOut()  # noqa: E501
        if include_optional:
            return MemberOwnershipOut(
                member_id = 56,
                reason_id = 56,
                access_package_id = 56,
                kind = 'order',
                status = 'active',
                granted_at = 56,
                is_test = True,
                period_end = 56,
                grace_until = 56
            )
        else:
            return MemberOwnershipOut(
                member_id = 56,
                reason_id = 56,
                access_package_id = 56,
                kind = 'order',
                status = 'active',
                granted_at = 56,
                is_test = True,
                period_end = 56,
                grace_until = 56,
        )
        """

    def testMemberOwnershipOut(self):
        """Test MemberOwnershipOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
