# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from access_server_connector.models.access_result_out import AccessResultOut
from access_server_connector.models.module_tree_out import ModuleTreeOut

class CourseTreeOut(BaseModel):
    """
    CourseTreeOut
    """
    course: AccessResultOut = Field(...)
    modules: conlist(ModuleTreeOut) = Field(...)
    next_transition: Optional[StrictInt] = Field(...)
    __properties = ["course", "modules", "next_transition"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CourseTreeOut:
        """Create an instance of CourseTreeOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of course
        if self.course:
            _dict['course'] = self.course.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in modules (list)
        _items = []
        if self.modules:
            for _item in self.modules:
                if _item:
                    _items.append(_item.to_dict())
            _dict['modules'] = _items
        # set to None if next_transition (nullable) is None
        # and __fields_set__ contains the field
        if self.next_transition is None and "next_transition" in self.__fields_set__:
            _dict['next_transition'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CourseTreeOut:
        """Create an instance of CourseTreeOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CourseTreeOut.parse_obj(obj)

        _obj = CourseTreeOut.parse_obj({
            "course": AccessResultOut.from_dict(obj.get("course")) if obj.get("course") is not None else None,
            "modules": [ModuleTreeOut.from_dict(_item) for _item in obj.get("modules")] if obj.get("modules") is not None else None,
            "next_transition": obj.get("next_transition")
        })
        return _obj


