# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_package_detail_out import WrappedResponsePackageDetailOut  # noqa: E501

class TestWrappedResponsePackageDetailOut(unittest.TestCase):
    """WrappedResponsePackageDetailOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponsePackageDetailOut:
        """Test WrappedResponsePackageDetailOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponsePackageDetailOut`
        """
        model = WrappedResponsePackageDetailOut()  # noqa: E501
        if include_optional:
            return WrappedResponsePackageDetailOut(
                done = True,
                result = access_server_connector.models.package_detail_out.PackageDetailOut(
                    id = 56, 
                    portal_id = 56, 
                    title = '', 
                    payment_type = '', 
                    is_active = True, 
                    is_locked = True, 
                    direct_link_slug = '', 
                    sales_page_url = '', 
                    expired_message = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    rules = [
                        access_server_connector.models.rule_out.RuleOut(
                            id = 56, 
                            resource_type = 'course', 
                            resource_id = 56, 
                            access_mode = 'available', 
                            unlock_type = 'immediate', 
                            unlock_days = 56, 
                            unlock_weekday = 56, 
                            unlock_weekdays = [
                                56
                                ], 
                            unlock_date = 56, 
                            expiry_type = 'none', 
                            expiry_days = 56, 
                            expiry_date = 56, 
                            binding = 'lifetime', )
                        ], )
            )
        else:
            return WrappedResponsePackageDetailOut(
                result = access_server_connector.models.package_detail_out.PackageDetailOut(
                    id = 56, 
                    portal_id = 56, 
                    title = '', 
                    payment_type = '', 
                    is_active = True, 
                    is_locked = True, 
                    direct_link_slug = '', 
                    sales_page_url = '', 
                    expired_message = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    rules = [
                        access_server_connector.models.rule_out.RuleOut(
                            id = 56, 
                            resource_type = 'course', 
                            resource_id = 56, 
                            access_mode = 'available', 
                            unlock_type = 'immediate', 
                            unlock_days = 56, 
                            unlock_weekday = 56, 
                            unlock_weekdays = [
                                56
                                ], 
                            unlock_date = 56, 
                            expiry_type = 'none', 
                            expiry_days = 56, 
                            expiry_date = 56, 
                            binding = 'lifetime', )
                        ], ),
        )
        """

    def testWrappedResponsePackageDetailOut(self):
        """Test WrappedResponsePackageDetailOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
