# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.override_out import OverrideOut  # noqa: E501

class TestOverrideOut(unittest.TestCase):
    """OverrideOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OverrideOut:
        """Test OverrideOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OverrideOut`
        """
        model = OverrideOut()  # noqa: E501
        if include_optional:
            return OverrideOut(
                resource_type = 'course',
                resource_id = 56,
                is_active = True,
                rule = access_server_connector.models.rule_body_out.RuleBodyOut(
                    access_mode = null, 
                    unlock_type = null, 
                    unlock_days = 56, 
                    unlock_weekday = 56, 
                    unlock_weekdays = [
                        56
                        ], 
                    unlock_date = 56, 
                    expiry_type = null, 
                    expiry_days = 56, 
                    expiry_date = 56, 
                    binding = null, ),
                created_by = 56,
                created_at = 56
            )
        else:
            return OverrideOut(
                resource_type = 'course',
                resource_id = 56,
                is_active = True,
                rule = access_server_connector.models.rule_body_out.RuleBodyOut(
                    access_mode = null, 
                    unlock_type = null, 
                    unlock_days = 56, 
                    unlock_weekday = 56, 
                    unlock_weekdays = [
                        56
                        ], 
                    unlock_date = 56, 
                    expiry_type = null, 
                    expiry_days = 56, 
                    expiry_date = 56, 
                    binding = null, ),
                created_by = 56,
                created_at = 56,
        )
        """

    def testOverrideOut(self):
        """Test OverrideOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
