# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class LockReason(str, Enum):
    """
    LockReason
    """

    """
    allowed enum values
    """
    LAUNCH_DATE = 'launch_date'
    EXPIRED = 'expired'
    LOCKED = 'locked'
    HIDDEN = 'hidden'

    @classmethod
    def from_json(cls, json_str: str) -> LockReason:
        """Create an instance of LockReason from a JSON string"""
        return LockReason(json.loads(json_str))


