# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt
from access_server_connector.models.resource_type import ResourceType
from access_server_connector.models.rule_body import RuleBody

class OverrideItem(BaseModel):
    """
    OverrideItem
    """
    member_id: StrictInt = Field(...)
    resource_type: ResourceType = Field(...)
    resource_id: StrictInt = Field(...)
    is_active: Optional[StrictBool] = True
    rule: Optional[RuleBody] = None
    __properties = ["member_id", "resource_type", "resource_id", "is_active", "rule"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OverrideItem:
        """Create an instance of OverrideItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of rule
        if self.rule:
            _dict['rule'] = self.rule.to_dict()
        # set to None if rule (nullable) is None
        # and __fields_set__ contains the field
        if self.rule is None and "rule" in self.__fields_set__:
            _dict['rule'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OverrideItem:
        """Create an instance of OverrideItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OverrideItem.parse_obj(obj)

        _obj = OverrideItem.parse_obj({
            "member_id": obj.get("member_id"),
            "resource_type": obj.get("resource_type"),
            "resource_id": obj.get("resource_id"),
            "is_active": obj.get("is_active") if obj.get("is_active") is not None else True,
            "rule": RuleBody.from_dict(obj.get("rule")) if obj.get("rule") is not None else None
        })
        return _obj


