# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class PackageOut(BaseModel):
    """
    PackageOut
    """
    id: StrictInt = Field(...)
    portal_id: StrictInt = Field(...)
    title: StrictStr = Field(...)
    payment_type: StrictStr = Field(...)
    is_active: StrictBool = Field(...)
    is_locked: StrictBool = Field(...)
    direct_link_slug: Optional[StrictStr] = Field(...)
    sales_page_url: Optional[StrictStr] = Field(...)
    expired_message: Optional[StrictStr] = Field(...)
    created_at: StrictInt = Field(...)
    updated_at: StrictInt = Field(...)
    __properties = ["id", "portal_id", "title", "payment_type", "is_active", "is_locked", "direct_link_slug", "sales_page_url", "expired_message", "created_at", "updated_at"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PackageOut:
        """Create an instance of PackageOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if direct_link_slug (nullable) is None
        # and __fields_set__ contains the field
        if self.direct_link_slug is None and "direct_link_slug" in self.__fields_set__:
            _dict['direct_link_slug'] = None

        # set to None if sales_page_url (nullable) is None
        # and __fields_set__ contains the field
        if self.sales_page_url is None and "sales_page_url" in self.__fields_set__:
            _dict['sales_page_url'] = None

        # set to None if expired_message (nullable) is None
        # and __fields_set__ contains the field
        if self.expired_message is None and "expired_message" in self.__fields_set__:
            _dict['expired_message'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PackageOut:
        """Create an instance of PackageOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PackageOut.parse_obj(obj)

        _obj = PackageOut.parse_obj({
            "id": obj.get("id"),
            "portal_id": obj.get("portal_id"),
            "title": obj.get("title"),
            "payment_type": obj.get("payment_type"),
            "is_active": obj.get("is_active"),
            "is_locked": obj.get("is_locked"),
            "direct_link_slug": obj.get("direct_link_slug"),
            "sales_page_url": obj.get("sales_page_url"),
            "expired_message": obj.get("expired_message"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj


