# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector.api.individual_api import IndividualApi  # noqa: E501


class TestIndividualApi(unittest.IsolatedAsyncioTestCase):
    """IndividualApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = IndividualApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_batch_overrides_v1_individual_overrides_post(self) -> None:
        """Test case for batch_overrides_v1_individual_overrides_post

        Batch-write per-member access overrides  # noqa: E501
        """
        pass

    async def test_member_overrides_v1_individual_members_member_id_overrides_get(self) -> None:
        """Test case for member_overrides_v1_individual_members_member_id_overrides_get

        List a member's effective overrides (latest-wins)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
