# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.rule_body_out import RuleBodyOut  # noqa: E501

class TestRuleBodyOut(unittest.TestCase):
    """RuleBodyOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RuleBodyOut:
        """Test RuleBodyOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RuleBodyOut`
        """
        model = RuleBodyOut()  # noqa: E501
        if include_optional:
            return RuleBodyOut(
                access_mode = 'available',
                unlock_type = 'immediate',
                unlock_days = 56,
                unlock_weekday = 56,
                unlock_weekdays = [
                    56
                    ],
                unlock_date = 56,
                expiry_type = 'none',
                expiry_days = 56,
                expiry_date = 56,
                binding = 'lifetime'
            )
        else:
            return RuleBodyOut(
                access_mode = 'available',
                unlock_type = 'immediate',
                unlock_days = 56,
                unlock_weekday = 56,
                unlock_weekdays = [
                    56
                    ],
                unlock_date = 56,
                expiry_type = 'none',
                expiry_days = 56,
                expiry_date = 56,
                binding = 'lifetime',
        )
        """

    def testRuleBodyOut(self):
        """Test RuleBodyOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
