# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from access_server_connector.models.state import State

class CourseSummaryOut(BaseModel):
    """
    CourseSummaryOut
    """
    course_id: StrictInt = Field(...)
    state: State = Field(...)
    allowed: StrictBool = Field(...)
    reasons: conlist(StrictInt) = Field(...)
    expired_message: Optional[StrictStr] = None
    __properties = ["course_id", "state", "allowed", "reasons", "expired_message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CourseSummaryOut:
        """Create an instance of CourseSummaryOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if expired_message (nullable) is None
        # and __fields_set__ contains the field
        if self.expired_message is None and "expired_message" in self.__fields_set__:
            _dict['expired_message'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CourseSummaryOut:
        """Create an instance of CourseSummaryOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CourseSummaryOut.parse_obj(obj)

        _obj = CourseSummaryOut.parse_obj({
            "course_id": obj.get("course_id"),
            "state": obj.get("state"),
            "allowed": obj.get("allowed"),
            "reasons": obj.get("reasons"),
            "expired_message": obj.get("expired_message")
        })
        return _obj


