# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.access_mode import AccessMode  # noqa: E501

class TestAccessMode(unittest.TestCase):
    """AccessMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccessMode(self):
        """Test AccessMode"""
        # inst = AccessMode()

if __name__ == '__main__':
    unittest.main()
